
;;; cedet site-lisp configuration

(load "@SITELISP@/common/cedet" nil t)

;; If you wish to customize CEDET, you will need to follow the
;; directions in the INSTALL (installed in the documentation) file and
;; customize your ~/.emacs /before/ site-gentoo is loaded.
